netapp_ontap.models.cifs_domain_password_schedule API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_domain_password_schedule`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsDomainPasswordScheduleSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsDomainPasswordSchedule object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `schedule_day_of_week: str PATCH`

    Day of the week for password change schedule.

    Example: Sunday

  `schedule_description: str GET`

    Schedule description.

  `schedule_enabled: bool GET POST PATCH`

    Is password schedule enabled.

  `schedule_last_changed_time: ImpreciseDateTime GET`

    Last successful password change time.

  `schedule_randomized_minute: Size GET POST PATCH`

    Minutes within which schedule start can be randomized.

  `schedule_time_of_day: str PATCH`

    Start time for password change schedule.

    Example: 36900

  `schedule_warn_message: str GET`

    Warning message in case job is deleted.

  `schedule_weekly_interval: Size GET POST PATCH`

    Interval in weeks for password change schedule.